--[[
    ezGroup - Presents a small popup, when invited to a group.
    Copyright (C) 2009 James Dunn (Protolif)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
]]


ezGroup = {}
ezGroup.version = 'ezGroup v0.1b'
ezGroup.main = {}
ezGroup.color = {} -- defining some colors
ezGroup.color.pastelGreen = '\12782FF82'
ezGroup.color.bloodRed = '\127800000'

function ezGroup.main:OnEvent(currentEvent,arg) -- Goes ding when there's stuff.
	ezGroup.currentEvent = currentEvent  -- 
	ezGroup.currentEventArg = arg
	if ezGroup.currentEvent == 'GROUP_SELF_INVITED' then  -- 
		ezGroup.myName = GetUserName()  -- Who are you? Cornelius? Rupert? Travis?
		ezGroup.groupRequester = ezGroup.currentEventArg -- the inviting player's name comes as an argument to the event
		ezGroup.playerFactionID = GetPlayerFaction(GetCharacterIDByName(ezGroup.groupRequester)) -- queries their nationality, with some success
		ezGroup.playerFactionRGB = FactionColor_RGB[ezGroup.playerFactionID] -- gets the RGB color string for the given factionid
		ezGroup.playerColorStr = ezGroup.playerFactionRGB..' 255 *' -- sets the opacity.

		-- oh look. a popup.
		ezGroup.popup = iup.dialog { 
			iup.vbox {
				iup.label {
					title = ' Group invitation from: ',
					expand = 'HORIZONTAL',
					alignment = 'ACENTER',
				},
				iup.label {
					title = ezGroup.groupRequester,
					expand = 'HORIZONTAL',
					alignment = 'ACENTER',
					fgcolor = ezGroup.playerColorStr, -- sets the color of their name to match their faction
				},
				iup.stationbutton {
					title = 'Accept',
					action = function(self)
						Group.Join(ezGroup.groupRequester) -- joins you to the group
						ezGroup.popup:hide()
					end,
					expand = 'HORIZONTAL',
				},
				iup.stationbutton {
					title = 'Decline',
					action = function(self)
						SendChat('No, thank you.', 'PRIVATE', ezGroup.groupRequester) -- since there is no Group.Decline(), we send a polite msg
						purchaseprint(ezGroup.color.pastelGreen..'->'..ezGroup.groupRequester..': '..'No, thank you.') -- this bit shows you the outgoing msg
						ezGroup.popup:hide()
					end,
					expand = 'HORIZONTAL',
				},
			},
		}
		ezGroup.popup.bgcolor = '0 0 0 50 *'
		ezGroup.popup.border = 'YES'
		ezGroup.popup.resize = 'NO'
		ezGroup.popup.maxbox = 'NO'
		ezGroup.popup.minbox = 'NO'
		ezGroup.popup.menubox = 'NO'
		ezGroup.popup.fullscreen = 'NO'
		ezGroup.popup.topmost = 'YES'
		ezGroup.popup.active = 'YES'
		ezGroup.popup:showxy(iup.CENTER, iup.BOTTOM)
	end
end

function ezGroup.groupInvite(data, args) -- shorthand for '/group invite playername'
	if args then
		ezGroup.groupInvitee = args[1]
		Group.Invite(ezGroup.groupInvitee)
	else
		purchaseprint(ezGroup.color.bloodRed..'The ezGroup /inv command must be followed by a playername. Syntax:')
		purchaseprint(ezGroup.color.bloodRed..'/inv playername')
	end
end

function ezGroup.groupKick(data, args) -- shorthand for '/group kick playername'
	if args then
		ezGroup.groupDBag = args[1]
		Group.Kick(ezGroup.groupDBag)
	else
		purchaseprint(ezGroup.color.bloodRed..'The ezGroup /kick command must be followed by a playername. Syntax:')
		purchaseprint(ezGroup.color.bloodRed..'/kick playername')
	end
end

function ezGroup.whisper(data, args) -- shorthand for '/msg playername message'  NOTE: does not like semicolons
	if args then
		ezGroup.whisperTo = args[1]
		ezGroup.secretMsg = ''
		for i,v in ipairs(args) do -- this bit basicically cats all the arguments into a string, except the first one.
			if v ~= ezGroup.whisperTo then
				ezGroup.secretMsg = ezGroup.secretMsg .. tostring(v) .. ' '
			end
		end
		purchaseprint(ezGroup.color.pastelGreen..'->'..ezGroup.whisperTo..': '..ezGroup.secretMsg) -- this bit shows you the outgoing msg
		SendChat(ezGroup.secretMsg, 'PRIVATE', ezGroup.whisperTo)
	else
		purchaseprint(ezGroup.color.bloodRed..'The ezGroup /w command must be followed by a playername. Syntax:')
		purchaseprint(ezGroup.color.bloodRed..'/w playername message')
	end
end

function ezGroup.groupLeave() -- instead of typing /group leave
	Group.Leave()
end

-- registration
RegisterUserCommand('inv', ezGroup.groupInvite)
RegisterUserCommand('kick', ezGroup.groupKick)
RegisterUserCommand('w', ezGroup.whisper)
RegisterUserCommand('gleave', ezGroup.groupLeave)
RegisterEvent(ezGroup.main, 'GROUP_SELF_INVITED')
